import { Observable } from 'rxjs';
import { MainService } from '../main/main.service';
import { TaxonomyVocabulary, TaxonomyVocabularyTree } from '../models/taxonomy-vocabulary';
/**
 * taxonomy vocabulary service for drupal
 * @see BACK_END/admin/structure/services/list/END_POINT/resources for more details
 */
export declare class TaxonomyVocabularyService extends MainService {
    entityType: string;
    /**
     * implement index resource
     * @return array of the available vocabularies
     */
    getAllVocabularies(): Observable<TaxonomyVocabulary[]>;
    /**
     * implement retrive resource
     * @param vid vocabulary id
     * @return vocabulary object
     */
    getTaxonomyVocabularyById(vid: number): Observable<TaxonomyVocabulary>;
    /**
     * implement create resource
     * @param taxonomyVocabulary the vocabulary to create
     * @return array of vocabulary id
     */
    createTaxonomyVocabulary(taxonomyVocabulary: TaxonomyVocabulary): Observable<number[]>;
    /**
     * implement update resource
     * @param taxonomyVocabulary the vocabulary to update
     * @return array of the current vocabulary whight
     */
    updateTaxonomyVocabulary(taxonomyVocabulary: TaxonomyVocabulary): Observable<number[]>;
    /**
     * implement delete resource
     * @param vid vocabulary id to delete
     * @return array of deleted vocabulary id
     */
    deleteTaxonomyVocabulary(vid: number): Observable<number[]>;
    /**
     * implement retrieveByMachineName resource
     * @param vocabularyMachineName vocabulary machine name
     * @return vocabulary object
     */
    getTaxonomyVocabularyByMachineName(vocabularyMachineName: string): Observable<TaxonomyVocabulary>;
    /**
     * implement getTree resource
     * @param vid vocabulary id
     * @return a full list of taxonomy terms inside this vocabulary as a tree structure.
     */
    getTaxonomyVocabularyTree(vid: number): Observable<TaxonomyVocabularyTree[]>;
}
